local Camera = require("lib.camera")
local map = require("scripts.map")

local LightWorld = require("lib.lightworld")

function love.load()
    love.graphics.setBackgroundColor(love.math.colorFromBytes(41, 45, 65))

    love.physics.setMeter(64)
    world = love.physics.newWorld(0, 9.81*64, true)

    windowWidth = love.graphics.getWidth()
    windowHeight = love.graphics.getHeight()

    lightWorld = LightWorld({
        ambient = {0.21, 0.21, 0.21},
    })

    lightMouse = lightWorld:newLight(0, 0, 1, 0.49, 0.24, 300)
    lightMouse:setGlowStrength(0.3)

    map:load()
end

function love.update(dt)
    if love.keyboard.isDown('escape') then love.event.quit() end

    lightWorld:update(dt)
    lightWorld:setTranslation(0, 0, map.scale)
    lightMouse:setPosition(love.mouse.getX(), love.mouse.getY())
end

function love.draw()
    love.graphics.push()

    love.graphics.scale(map.scale)
    lightWorld:draw(function()
        map:draw()
    end)

    love.graphics.pop()
end